@@ -660,7 +660,7 @@ def update_app_utils(appname, branch, keys=False, reboot=False):
         run('tar zxf %s.tar.gz -C %s' % (TAR_NAME, APP_UTILS_DIR))
 
     # run the "instanceType"-command.sh in the appropriate branch
-    cmdToRun = "sudo --preserve-env=HOME /home/ubuntu/" + appname + "/" + APP_UTILS_DIR + "/config/" + ENVIRONMENT + "/${dc_TAG_Type}-commands.sh"
+    cmdToRun = "sudo /home/ubuntu/" + appname + "/" + APP_UTILS_DIR + "/config/" + ENVIRONMENT + "/${dc_TAG_Type}-commands.sh"
     run(cmdToRun)
 
     # run deployenv on the instance to get the new values into /etc/enviornmnet
